@@ -10,9 +10,10 @@
 #ifndef ICONIMAGEPROVIDER_H
 #define ICONIMAGEPROVIDER_H
 
-#include <QQmlApplicationEngine>
 #include <QQuickImageProvider>
 
+class QQmlApplicationEngine;
+
 class IconImageProvider : public QQuickImageProvider
 {
 public:
